Top

    Atlantic Regional Qualifier
    Washington, D.C.
    June 12th 2004
    33 players
    Matt Morgan

    Deck Name:   Call me Julio
    Description: POT/DOM is always good.  Let's add permanent rush, +strength,
    Nosferatu Kingdom and a bad attitude!

    Crypt (12 cards, min=20, max=37, avg=7.33)
    ------------------------------------------
    3x Julio Martinez			9   ANI DOM OBF POT nec	 bishop		Nosferatu antitribu:3
    2x Tarbaby Jack				8   ANI OBF POT dom ser	 		Nosferatu antitribu:3
    1x Cailean				10  ANI OBF POT PRE dom	 archbishop	Nosferatu antitribu:2
    1x Mateusz Gryzbowsky			8   ANI OBF POT		 		Nosferatu antitribu:3
    1x Beast, The Leatherface of Detroit	7   OBF POT ani cel	 		Nosferatu antitribu:2
    1x Ox, Viceroy of the Hollows		6   ANI OBF POT		 		Nosferatu antitribu:2
    1x Nigel the Shunned			5   ANI POT obf		 		Nosferatu antitribu:2
    1x Olivia				5   OBF POT vic		 bishop		Nosferatu antitribu:2
    1x Agatha				4   POT obf		 		Nosferatu antitribu:2

    You can see from the crypt that an important part of playing this deck
    is being incredibly lucky.  I drew Beast in three out of four games and
    I drew Julio in every one.  How'd I get so lucky?  Dunno, I got a horrible
    crypt draw in a casual game on Friday.

    Library (90)
    Master (13)
    4  Blood Doll --Not enough unless you're lucky (like I was).
    2  Dominate /* Didn't really use them, but they were supposed to justify the crypt
    spread.  If there's no Julio, a Tarbaby or Cailean and a Dominate master
    is nearly as good, right? */
    1  Dreams of the Sphinx
    2  Fame
    1  Information Network -- Played it, but never tapped it.
    2  Nosferatu Kingdom -- Absolutely essential.  Always got one after the other, though.

    1  Shanty Town Hunting Ground

    Action (12)
    6  Bum's Rush
    6  Govern the Unaligned -- Almost always played superior.

    Action Modifier (4)
    4  Conditioning -- Because Colin said it was a good idea (he's right).

    Reaction (15)
    8  Deflection
    7  Wake with Evening's Freshness -- Replace one with Mylan Horseed as soon as Gehenna is legal.

    Combat (42)
    3  Behind You!
    4  Carrion Crows
    10 Immortal Grapple
    6  Taste of Vitae
    10 Torn Signpost
    9  Undead Strength

    Combo (4)
    4  Swallowed by the Night

    I've discussed some of the combat above and in other threads.
    In many ways, it's your basic Potence package.  The key is the guys with
    +strength.  The first time they beat someone down, they'll need a few
    cards (or a lot of cards) to do so.  After that, a Grapple might not
    even be necessary.  Pure goodness.

    An earlier version of the deck used Guardian Angels to avoid agg pokes
    and similar, but I took them out of the final version reasoning that most
    of the combat I see in tournaments is potence combat or guns and also that
    considering the expense of my minions, my masters should gain me pool, not
    cost pool.  I also had some Gang Tactics in an earlier version just because
    I think the art on them is hysterical and they're kind of useful.
    They were ultimately dropped for maneuvers because it seems more useful to
    me to be able to hold the maneuvers and play them in combat as needed than
    it is to assume I'll want close range on a certain action.  Now that I've
    won a tournament with this deck, I might put them back in just for fun.